@@ -23,6 +23,7 @@ modules = [
     "8muses",
     "adultempire",
     "agnph",
+    "ahottie",
     "ao3",
     "arcalive",
     "architizer",
@@ -233,6 +234,7 @@ modules = [
     "weebcentral",
     "weebdex",
     "weibo",
+    "whyp",
     "wikiart",
     "wikifeet",
     "wikimedia",
@@ -242,6 +244,7 @@ modules = [
     "xhamster",
     "xvideos",
     "yiffverse",
+    "yourlesbians",
     "zerochan",
     "booru",
     "moebooru",
