@@ -9,7 +9,6 @@
 from .common import Extractor, Message
 from .. import text, exception
 
-
 BASE_PATTERN = r"(?:https?://)?discord\.com"
 
 
@@ -19,11 +18,9 @@ class DiscordExtractor(Extractor):
     root = "https://discord.com"
     directory_fmt = ("{category}", "{server_id}_{server}",
                      "{channel_id}_{channel}")
-    filename_fmt = "{message_id}_{num:>02}_{filename}.{extension}"
+    filename_fmt = "{message_id}_{num:>02}_{filename[:220]}.{extension}"
     archive_fmt = "{message_id}_{num}"
 
-    cdn_fmt = "https://cdn.discordapp.com/{}/{}/{}.png?size=4096"
-
     server_metadata = {}
     server_channels_metadata = {}
 
@@ -74,9 +71,7 @@ class DiscordExtractor(Extractor):
                 "author_files": [],
                 "message": self.extract_message_text(message),
                 "message_id": message["id"],
-                "date": text.parse_datetime(
-                    message["timestamp"], "%Y-%m-%dT%H:%M:%S.%f%z"
-                ),
+                "date": self.parse_datetime_iso(message["timestamp"]),
                 "files": []
             })
 
@@ -86,44 +81,50 @@ class DiscordExtractor(Extractor):
             ):
                 if message["author"].get(icon_type):
                     message_metadata["author_files"].append({
-                        "url": self.cdn_fmt.format(
-                            icon_path,
-                            message_metadata["author_id"],
-                            message["author"][icon_type]
-                        ),
+                        "url": (f"https://cdn.discordapp.com/{icon_path}/"
+                                f"{message_metadata['author_id']}/"
+                                f"{message['author'][icon_type]}.png"
+                                f"?size=4096"),
                         "filename": icon_type,
                         "extension": "png",
                     })
 
-            for attachment in message["attachments"]:
-                message_metadata["files"].append({
-                    "url": attachment["url"],
-                    "type": "attachment",
-                })
+            message_snapshots = [message]
+            message_snapshots.extend(
+                msg["message"] for msg in message.get("message_snapshots", [])
+                if msg["message"]["type"] in (0, 19, 21)
+            )
 
-            for embed in message["embeds"]:
-                if embed["type"] in self.enabled_embeds:
-                    for field in ("video", "image", "thumbnail"):
-                        if field not in embed:
-                            continue
-                        url = embed[field].get("proxy_url")
-                        if url is not None:
-                            message_metadata["files"].append({
-                                "url": url,
-                                "type": "embed",
-                            })
-                            break
+            for snapshot in message_snapshots:
+                for attachment in snapshot["attachments"]:
+                    message_metadata["files"].append({
+                        "url": attachment["url"],
+                        "type": "attachment",
+                    })
 
-            for num, file in enumerate(message_metadata["files"], start=1):
-                text.nameext_from_url(file["url"], file)
-                file["num"] = num
+                for embed in snapshot["embeds"]:
+                    if embed["type"] in self.enabled_embeds:
+                        for field in ("video", "image", "thumbnail"):
+                            if field not in embed:
+                                continue
+                            url = embed[field].get("proxy_url")
+                            if url is not None:
+                                message_metadata["files"].append({
+                                    "url": url,
+                                    "type": "embed",
+                                })
+                                break
 
-            yield Message.Directory, message_metadata
+                for num, file in enumerate(message_metadata["files"], start=1):
+                    text.nameext_from_url(file["url"], file)
+                    file["num"] = num
 
-            for file in message_metadata["files"]:
-                message_metadata_file = message_metadata.copy()
-                message_metadata_file.update(file)
-                yield Message.Url, file["url"], message_metadata_file
+                yield Message.Directory, "", message_metadata
+
+                for file in message_metadata["files"]:
+                    message_metadata_file = message_metadata.copy()
+                    message_metadata_file.update(file)
+                    yield Message.Url, file["url"], message_metadata_file
 
     def extract_channel_text(self, channel_id):
         for message in self.api.get_channel_messages(channel_id):
@@ -158,7 +159,7 @@ class DiscordExtractor(Extractor):
                         yield from self.extract_channel(
                             channel["channel_id"], safe=True)
             elif not safe:
-                raise exception.StopExtraction(
+                raise exception.AbortExtraction(
                     "This channel type is not supported."
                 )
         except exception.HttpError as exc:
@@ -201,31 +202,47 @@ class DiscordExtractor(Extractor):
 
     def parse_server(self, server):
         self.server_metadata = {
-            "server": server["name"],
+            "server"   : server["name"],
             "server_id": server["id"],
-            "server_files": [],
-            "owner_id": server["owner_id"]
+            "owner_id" : server["owner_id"],
+            "server_files": self.collect_server_assets(server),
         }
 
-        for icon_type, icon_path in (
-            ("icon", "icons"),
-            ("banner", "banners"),
-            ("splash", "splashes"),
-            ("discovery_splash", "discovery-splashes")
-        ):
-            if server.get(icon_type):
-                self.server_metadata["server_files"].append({
-                    "url": self.cdn_fmt.format(
-                        icon_path,
-                        self.server_metadata["server_id"],
-                        server[icon_type]
-                    ),
-                    "filename": icon_type,
-                    "extension": "png",
-                })
-
         return self.server_metadata
 
+    def collect_server_assets(self, server, asset_type=None):
+        if asset_type and asset_type != "general":
+            return [
+                {
+                    **asset,
+                    "url": (f"https://cdn.discordapp.com/{asset_type}/"
+                            f"{asset['id']}.png?size=4096"),
+                    "label"    : asset_type,
+                    "filename" : f"{asset['name']} ({asset['id']})",
+                    "extension": "png",
+                }
+                for asset in assets
+            ] if (assets := server.get(asset_type)) else ()
+        else:
+            return [
+                {
+                    "url": (f"https://cdn.discordapp.com/{asset_path}/"
+                            f"{server['id']}/{asset_id}.png?size=4096"),
+                    "id"       : f"{server['id']}/{asset_id}",
+                    "label"    : "",
+                    "name"     : asset_type,
+                    "filename" : asset_type,
+                    "extension": "png",
+                }
+                for asset_type, asset_path in (
+                    ("icon"  , "icons"),
+                    ("banner", "banners"),
+                    ("splash", "splashes"),
+                    ("discovery_splash", "discovery-splashes")
+                )
+                if (asset_id := server.get(asset_type))
+            ]
+
     def build_server_and_channels(self, server_id):
         self.parse_server(self.api.get_server(server_id))
 
@@ -266,6 +283,35 @@ class DiscordMessageExtractor(DiscordExtractor):
             self.api.get_message(channel_id, message_id))
 
 
+class DiscordServerAssetsExtractor(DiscordExtractor):
+    subcategory = "server-assets"
+    filename_fmt = "{name} ({id}).{extension}"
+    directory_fmt = ["{category}", "{server_id}_{server}", "Assets", "{label}"]
+    archive_fmt = "asset_{server_id}_{id}"
+    pattern = (BASE_PATTERN +
+               r"/channels/(\d+)/(?:assets?|files)(?:/([\w-]+))?/?$")
+    example = "https://discord.com/channels/1234567890/assets"
+
+    def items(self):
+        server_id, asset_type = self.groups
+        server = self.api.get_server(server_id)
+        parsed = self.parse_server(server)
+
+        if asset_type is None:
+            asset_types = ("", "emojis", "stickers")
+        else:
+            asset_types = asset_type.split(",")
+
+        for asset_type in asset_types:
+            assets = self.collect_server_assets(server, asset_type)
+            parsed["count"] = len(assets)
+            parsed["label"] = asset_type
+            yield Message.Directory, "", parsed
+            for asset in assets:
+                asset.update(parsed)
+                yield Message.Url, asset["url"], asset
+
+
 class DiscordServerExtractor(DiscordExtractor):
     subcategory = "server"
     pattern = BASE_PATTERN + r"/channels/(\d+)/?$"
@@ -342,7 +388,7 @@ class DiscordAPI():
                 "sort_order": "desc",
                 "limit": THREADS_BATCH,
                 "offset": + offset,
-            })["threads"]
+            }).get("threads", [])
 
         return self._pagination(_method, THREADS_BATCH)
 
@@ -391,8 +437,7 @@ class DiscordAPI():
                 return
             offset += len(data)
 
-    @staticmethod
-    def _raise_invalid_token():
+    def _raise_invalid_token(self):
         raise exception.AuthenticationError("""Invalid or missing token.
 Please provide a valid token following these instructions:
 
