@@ -35,8 +35,7 @@ class GelbooruV01Extractor(booru.BooruExtractor):
         }
 
         post["md5"] = post["file_url"].rpartition("/")[2].partition(".")[0]
-        post["date"] = text.parse_datetime(
-            post["created_at"], "%Y-%m-%d %H:%M:%S")
+        post["date"] = self.parse_datetime_iso(post["created_at"])
 
         return post
 
