@@ -22,14 +22,14 @@ class GirlsreleasedExtractor(Extractor):
 
     def items(self):
         data = {"_extractor": GirlsreleasedSetExtractor}
-        base = f"{self.root}/set/"
+        base = self.root + "/set/"
         for set in self._pagination():
-            yield Message.Queue, f"{base}{set[0]}", data
+            yield Message.Queue, base + set[0], data
 
     def _pagination(self):
         base = f"{self.root}/api/0.2/sets/{self._path}/{self.groups[0]}/page/"
         for pnum in itertools.count():
-            sets = self.request_json(f"{base}{pnum}")["sets"]
+            sets = self.request_json(base + str(pnum))["sets"]
             if not sets:
                 return
 
@@ -41,7 +41,7 @@ class GirlsreleasedExtractor(Extractor):
 class GirlsreleasedSetExtractor(GirlsreleasedExtractor):
     """Extractor for girlsreleased galleries"""
     subcategory = "set"
-    pattern = rf"{BASE_PATTERN}/set/(\d+)"
+    pattern = BASE_PATTERN + r"/set/(\d+)"
     example = "https://girlsreleased.com/set/12345"
 
     def items(self):
@@ -65,12 +65,12 @@ class GirlsreleasedSetExtractor(GirlsreleasedExtractor):
 class GirlsreleasedModelExtractor(GirlsreleasedExtractor):
     """Extractor for girlsreleased models"""
     subcategory = _path = "model"
-    pattern = rf"{BASE_PATTERN}/model/(\d+(?:/.+)?)"
+    pattern = BASE_PATTERN + r"/model/(\d+(?:/.+)?)"
     example = "https://girlsreleased.com/model/12345/MODEL"
 
 
 class GirlsreleasedSiteExtractor(GirlsreleasedExtractor):
     """Extractor for girlsreleased sites"""
     subcategory = _path = "site"
-    pattern = rf"{BASE_PATTERN}/site/([^/?#]+(?:/model/\d+/?.*)?)"
+    pattern = BASE_PATTERN + r"/site/([^/?#]+(?:/model/\d+/?.*)?)"
     example = "https://girlsreleased.com/site/SITE"
