@@ -51,8 +51,8 @@ class RedgifsExtractor(Extractor):
 
             gif.update(metadata)
             gif["count"] = cnt
-            gif["date"] = text.parse_timestamp(gif.get("createDate"))
-            yield Message.Directory, gif
+            gif["date"] = self.parse_timestamp(gif.get("createDate"))
+            yield Message.Directory, "", gif
 
             for num, gif in enumerate(gifs, enum):
                 gif["_fallback"] = formats = self._formats(gif)
@@ -135,7 +135,7 @@ class RedgifsCollectionsExtractor(RedgifsExtractor):
     def items(self):
         base = f"{self.root}/users/{self.key}/collections/"
         for collection in self.api.collections(self.key):
-            url = f"{base}{collection['folderId']}"
+            url = base + collection["folderId"]
             collection["_extractor"] = RedgifsCollectionExtractor
             yield Message.Queue, url, collection
 
