@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# Copyright 2015-2022 Mike Fährmann
+# Copyright 2015-2025 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -11,8 +11,6 @@ import os
 import sys
 import unittest
 
-import datetime
-
 sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 from gallery_dl import text, util  # noqa E402
 
@@ -23,6 +21,20 @@ INVALID_ALT = ((), [], {}, None, "")
 
 class TestText(unittest.TestCase):
 
+    def test_re(self):
+        p1 = text.re_compile("foo")
+        p2 = text.re("foo")
+        p3 = text.re("foo")
+
+        Pattern = text.re_module.Pattern
+        self.assertIsInstance(p1, Pattern)
+        self.assertIsInstance(p2, Pattern)
+        self.assertIsInstance(p3, Pattern)
+
+        self.assertEqual(p1, p2)
+        self.assertIsNot(p1, p2)
+        self.assertIs(p2, p3)
+
     def test_remove_html(self, f=text.remove_html):
         result = "Hello World."
 
@@ -92,6 +104,17 @@ class TestText(unittest.TestCase):
         self.assertEqual(f(1), "1")
         self.assertEqual(f(2.3), "23")
 
+    def test_sanitize_whitespace(self, f=text.sanitize_whitespace):
+        self.assertEqual(f("Hello World"), "Hello World")
+        self.assertEqual(f("Hello\tWorld"), "Hello World")
+        self.assertEqual(f("  Hello   World  "), "Hello World")
+        self.assertEqual(f("\tHello  \n\tWorld  "), "Hello World")
+
+        self.assertEqual(f(""), "")
+        self.assertEqual(f(" "), "")
+        self.assertEqual(f("      "), "")
+        self.assertEqual(f(" \t\n "), "")
+
     def test_ensure_http_scheme(self, f=text.ensure_http_scheme):
         result = "https://example.org/filename.ext"
 
@@ -178,6 +201,10 @@ class TestText(unittest.TestCase):
         self.assertEqual(f("http://example.org/v2/filename.ext"), result)
         self.assertEqual(
             f("http://example.org/v2/filename.ext?param=value#frag"), result)
+        self.assertEqual(
+            f("http://example.org/v2/foo%202?bar&<>.ext?param=value#frag"),
+            {"filename": "foo 2", "extension": ""},
+        )
 
         # long "extension"
         fn = "httpswww.example.orgpath-path-path-path-path-path-path-path"
@@ -187,6 +214,24 @@ class TestText(unittest.TestCase):
         for value in INVALID:
             self.assertEqual(f(value), empty)
 
+    def test_nameext_from_name(self, f=text.nameext_from_name):
+        self.assertEqual(
+            f(""),
+            {"filename": "", "extension": ""},
+        )
+        self.assertEqual(
+            f("filename.ext"),
+            {"filename": "filename", "extension": "ext"},
+        )
+        self.assertEqual(
+            f("foo%202?bar&<>.ext"),
+            {"filename": "foo%202?bar&<>", "extension": "ext"},
+        )
+
+        # long "extension"
+        fn = "httpswww.example.orgpath-path-path-path-path-path-path-path"
+        self.assertEqual(f(fn), {"filename": fn, "extension": ""})
+
     def test_extract(self, f=text.extract):
         txt = "<a><b>"
         self.assertEqual(f(txt, "<", ">"), ("a" , 3))
@@ -241,6 +286,29 @@ class TestText(unittest.TestCase):
             self.assertEqual(f(txt  , value, ">")  , (None, -1))
             self.assertEqual(f(txt  , "<"  , value), (None, -1))
 
+    def test_rextr(self, f=text.rextr):
+        txt = "<a><b>"
+        self.assertEqual(f(txt, "<", ">"), "b")
+        self.assertEqual(f(txt, "X", ">"), "")
+        self.assertEqual(f(txt, "<", "X"), "")
+
+        # 'pos' argument
+        for i in range(10, 3, -1):
+            self.assertEqual(f(txt, "<", ">", i), "b")
+        for i in range(3, 0, -1):
+            self.assertEqual(f(txt, "<", ">", i), "a")
+
+        # 'default' argument
+        self.assertEqual(f(txt, "[", "]", -1, "none"), "none")
+        self.assertEqual(f(txt, "[", "]", None, "none"), "none")
+        self.assertEqual(f(txt, "[", "]", default="none"), "none")
+
+        # invalid arguments
+        for value in INVALID:
+            self.assertEqual(f(value, "<"  , ">")  , "")
+            self.assertEqual(f(txt  , value, ">")  , "")
+            self.assertEqual(f(txt  , "<"  , value), "")
+
     def test_extract_all(self, f=text.extract_all):
         txt = "[c][b][a]: xyz! [d][e"
 
@@ -336,6 +404,8 @@ class TestText(unittest.TestCase):
         )
 
     def test_parse_bytes(self, f=text.parse_bytes):
+        self.assertEqual(f(0), 0)
+        self.assertEqual(f(50), 50)
         self.assertEqual(f("0"), 0)
         self.assertEqual(f("50"), 50)
         self.assertEqual(f("50k"), 50 * 1024**1)
@@ -343,10 +413,13 @@ class TestText(unittest.TestCase):
         self.assertEqual(f("50g"), 50 * 1024**3)
         self.assertEqual(f("50t"), 50 * 1024**4)
         self.assertEqual(f("50p"), 50 * 1024**5)
+        self.assertEqual(f(" 50p "), 50 * 1024**5)
 
         # fractions
+        self.assertEqual(f(123.456), 123)
         self.assertEqual(f("123.456"), 123)
         self.assertEqual(f("123.567"), 124)
+        self.assertEqual(f(" 123.89 "), 124)
         self.assertEqual(f("0.5M"), round(0.5 * 1024**2))
 
         # invalid arguments
@@ -405,8 +478,16 @@ class TestText(unittest.TestCase):
 
         # missing value
         self.assertEqual(f("bar"), {})
+        self.assertEqual(f("bar="), {"bar": ""})
+        self.assertEqual(f("bar", empty=True), {"bar": ""})
         self.assertEqual(f("foo=1&bar"), {"foo": "1"})
+        self.assertEqual(f("foo=1&bar="), {"foo": "1", "bar": ""})
+        self.assertEqual(f("foo=1&bar", True), {"foo": "1", "bar": ""})
         self.assertEqual(f("foo=1&bar&baz=3"), {"foo": "1", "baz": "3"})
+        self.assertEqual(f("foo=1&bar=&baz=3"),
+                         {"foo": "1", "bar": "", "baz": "3"})
+        self.assertEqual(f("foo=1&bar&baz=3", True),
+                         {"foo": "1", "bar": "", "baz": "3"})
 
         # keys with identical names
         self.assertEqual(f("foo=1&foo=2"), {"foo": "1"})
@@ -424,6 +505,8 @@ class TestText(unittest.TestCase):
         self.assertEqual(f(""), {})
         self.assertEqual(f("foo=1"), {"foo": "1"})
         self.assertEqual(f("foo=1&bar=2"), {"foo": "1", "bar": "2"})
+        self.assertEqual(f("%C3%A4%26=%E3%81%82%E3%81%A8&%23=%3F"),
+                         {"ä&": "あと", "#": "?"})
 
         # missing value
         self.assertEqual(f("bar"), {})
@@ -441,50 +524,20 @@ class TestText(unittest.TestCase):
         for value in INVALID:
             self.assertEqual(f(value), {})
 
-    def test_parse_timestamp(self, f=text.parse_timestamp):
-        null = util.datetime_utcfromtimestamp(0)
-        value = util.datetime_utcfromtimestamp(1555816235)
+    def test_build_query(self, f=text.build_query):
+        # standard usage
+        self.assertEqual(f({}), "")
+        self.assertEqual(f({"foo": "1"}), "foo=1")
+        self.assertEqual(f({"foo": "1", "bar": "2"}), "foo=1&bar=2")
 
-        self.assertEqual(f(0)           , null)
-        self.assertEqual(f("0")         , null)
-        self.assertEqual(f(1555816235)  , value)
-        self.assertEqual(f("1555816235"), value)
+        # missing value
+        self.assertEqual(f({"bar": ""}), "bar=")
+        self.assertEqual(f({"foo": "1", "bar": ""}), "foo=1&bar=")
+        self.assertEqual(f({"foo": "1", "bar": "", "baz": "3"}),
+                         "foo=1&bar=&baz=3")
 
-        for value in INVALID_ALT:
-            self.assertEqual(f(value), None)
-            self.assertEqual(f(value, "foo"), "foo")
-
-    def test_parse_datetime(self, f=text.parse_datetime):
-        null = util.datetime_utcfromtimestamp(0)
-
-        self.assertEqual(f("1970-01-01T00:00:00+00:00"), null)
-        self.assertEqual(f("1970-01-01T00:00:00+0000") , null)
-        self.assertEqual(f("1970.01.01", "%Y.%m.%d")   , null)
-
-        self.assertEqual(
-            f("2019-05-07T21:25:02+09:00"),
-            datetime.datetime(2019, 5, 7, 12, 25, 2),
-        )
-        self.assertEqual(
-            f("2019-05-07T21:25:02+0900"),
-            datetime.datetime(2019, 5, 7, 12, 25, 2),
-        )
-        self.assertEqual(
-            f("2019-05-07T21:25:02.753+0900", "%Y-%m-%dT%H:%M:%S.%f%z"),
-            datetime.datetime(2019, 5, 7, 12, 25, 2),
-        )
-        self.assertEqual(
-            f("2019-05-07T21:25:02", "%Y-%m-%dT%H:%M:%S", utcoffset=9),
-            datetime.datetime(2019, 5, 7, 12, 25, 2),
-        )
-        self.assertEqual(
-            f("2019-05-07 21:25:02"),
-            "2019-05-07 21:25:02",
-        )
-
-        for value in INVALID:
-            self.assertEqual(f(value), None)
-        self.assertEqual(f("1970.01.01"), "1970.01.01")
+        self.assertEqual(f({"ä&": "あと", "#": "?"}),
+                         "%C3%A4%26=%E3%81%82%E3%81%A8&%23=%3F")
 
 
 if __name__ == "__main__":
